summaryrefslogtreecommitdiff
path: root/lib/chef/cookbook_version.rb
diff options
context:
space:
mode:
authorXabier de Zuazo <xabier@onddo.com>2013-03-04 15:05:54 +0100
committerBryan McLellan <btm@opscode.com>2013-04-11 13:04:33 -0700
commit38becdf97cdbd060027776a551aad333fbddcd5a (patch)
tree1e193e818ca257424f1ab849e3862662bb6fc27a /lib/chef/cookbook_version.rb
parent8c1e41b93b119855e2e723cf35f9ca72d06a76f4 (diff)
downloadchef-38becdf97cdbd060027776a551aad333fbddcd5a.tar.gz
[CHEF-3919] cookbook version specific code factored out from Chef::Version, new classes created: Chef::Version::Cookbook and Chef::VersionConstraint::Cookbook
Diffstat (limited to 'lib/chef/cookbook_version.rb')
-rw-r--r--lib/chef/cookbook_version.rb8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/chef/cookbook_version.rb b/lib/chef/cookbook_version.rb
index a70c892e1b..61917fc889 100644
--- a/lib/chef/cookbook_version.rb
+++ b/lib/chef/cookbook_version.rb
@@ -25,7 +25,7 @@ require 'chef/resource_definition_list'
require 'chef/recipe'
require 'chef/cookbook/file_vendor'
require 'chef/cookbook/metadata'
-require 'chef/version_class'
+require 'chef/version/cookbook'
class Chef
@@ -669,9 +669,9 @@ class Chef
def <=>(o)
raise Chef::Exceptions::CookbookVersionNameMismatch if self.name != o.name
# FIXME: can we change the interface to the Metadata class such
- # that metadata.version returns a Chef::Version instance instead
- # of a string?
- Chef::Version.new(self.version) <=> Chef::Version.new(o.version)
+ # that metadata.version returns a Chef::Version::Cookbook instance
+ # instead of a string?
+ Chef::Version.new(self.version) <=> Chef::Version::Cookbook.new(o.version)
end
private